package com.caimei365.manager.controller.caimei.providers;

import com.caimei365.manager.entity.PaginationVo;
import com.caimei365.manager.entity.ResponseJson;
import com.caimei365.manager.entity.caimei.cmUser.CmClub;
import com.caimei365.manager.entity.caimei.providers.ServiceProviderModel;
import com.caimei365.manager.entity.caimei.product.Product;
import com.caimei365.manager.entity.caimei.providers.CmProviderTeam;
import com.caimei365.manager.entity.caimei.providers.CmProvidersContract;
import com.caimei365.manager.service.caimei.providers.CmProvidersContractService;
import com.caimei365.manager.service.caimei.providers.CmProvidersService;
import com.github.pagehelper.PageHelper;
import org.apache.commons.lang3.StringUtils;
import org.springframework.validation.annotation.Validated;
import org.springframework.web.bind.annotation.*;

import javax.annotation.Resource;
import javax.servlet.http.HttpServletRequest;
import javax.servlet.http.HttpServletResponse;
import javax.validation.constraints.NotNull;
import java.util.Date;
import java.util.List;

/**
 * 功能描述:服务商/协销功能已合并
 */
@Validated
@RestController
@RequestMapping("/providers")
public class ProvidersApi {
    @Resource
    private CmProvidersService cmProvidersService;
    @Resource
    private CmProvidersContractService cmProvidersContractService;


    /**
     * 修改服务商密码（协销功能合并）
     *
     * @param userId
     * @param password
     * @return
     */
    @GetMapping("/update/pass")
    public ResponseJson updatePassWord(Integer userId, String password) {
        return cmProvidersService.updatePassWord(userId, password);
    }

    /**
     * 编辑小组
     *
     * @param
     * @return
     */
    @PostMapping("/add/team")
    public ResponseJson addTeam(@RequestBody CmProviderTeam team) {
        return cmProvidersService.addTeam(team);
    }

    /**
     * 修改组长
     *
     * @param team
     * @return
     */
    @PostMapping("/update/leader")
    public ResponseJson updateLeader(@RequestBody CmProviderTeam team) {
        return cmProvidersService.updateLeader(team);
    }

    @GetMapping("/del/team")
    public ResponseJson delTeam(Integer id) {
        return cmProvidersService.delTeam(id);
    }

    /**
     * 小组成员列表
     *
     * @param id
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/groupList")
    public ResponseJson<PaginationVo<ServiceProviderModel>> groupList(Integer id,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return cmProvidersService.groupList(id, pageNum, pageSize);
    }

    /**
     * 添加成员列表
     *
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/addGroups")
    public ResponseJson<PaginationVo<ServiceProviderModel>> addGroups(String mobile, String name,
                                                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return cmProvidersService.addGroups(mobile, name, pageNum, pageSize);
    }

    @GetMapping("/del/group")
    public ResponseJson delGroup(Integer teamId, Integer spId) {
        return cmProvidersService.delGroup(teamId, spId);
    }

    @GetMapping("/add/group")
    public ResponseJson addGroup(Integer teamId, String spId) {
        return cmProvidersService.addGroup(teamId, spId);
    }

    /**
     * 服务商小组列表
     *
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/teamList")
    public ResponseJson<PaginationVo<CmProviderTeam>> providerTeam(@RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                   @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return cmProvidersService.providerTeam(pageNum, pageSize);
    }

    /**
     * 协销机构列表
     *
     * @param spId
     * @param clubId
     * @param name
     * @param linkMan
     * @param bindMobile
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/clubList")
    public ResponseJson<PaginationVo<CmClub>> clubList(@NotNull(message = "协销Id不能为空") Integer spId, Integer clubId,
                                                       String name, String linkMan, String bindMobile,
                                                       @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                       @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return cmProvidersService.clubList(spId, clubId, name, linkMan, bindMobile, pageNum, pageSize);
    }


    /**
     * 添加商品列表
     *
     * @param shopName
     * @param productName
     * @param productId
     * @param shopId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/product/list")
    public ResponseJson<PaginationVo<Product>> providersProductList(Integer serviceProviderId,
                                                                    String shopName,
                                                                    String productName,
                                                                    Integer productId,
                                                                    Integer shopId,
                                                                    @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                    @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return cmProvidersService.getProviderProducts(serviceProviderId, shopName, productName, productId, shopId, pageNum, pageSize);
    }

    /**
     * 服务商商品列表
     *
     * @param productName
     * @param productId
     * @param pageNum
     * @param pageSize
     * @return
     */
    @GetMapping("/products")
    public ResponseJson<PaginationVo<Product>> providersProducts(@NotNull(message = "服务商Id不能为空") Integer serviceProviderId,
                                                                 String productName, Integer productId,
                                                                 @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                                                 @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        return cmProvidersService.getProviderProductList(serviceProviderId, productName, productId, pageNum, pageSize);
    }

    @GetMapping("/add/products")
    public ResponseJson addProvidersProducts(Integer serviceProviderId, String productIds) {
        return cmProvidersService.addProvidersProducts(serviceProviderId, productIds);
    }

    @GetMapping("/del/products")
    public ResponseJson delProvidersProducts(Integer serviceProviderId, Integer productId) {
        return cmProvidersService.delProvidersProducts(serviceProviderId, productId);
    }

    @GetMapping("/list")
    public ResponseJson providersList(String name,
                                      Integer serviceLevel,
                                      Integer serviceCategory,
                                      String qualificationId,
                                      Date contractStartDate,
                                      Date contractEndDate,
                                      @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                      @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<ServiceProviderModel> cmProvidersList = cmProvidersService.getCmProvidersList(
                new ServiceProviderModel().setName(name).setServiceLevel(serviceLevel).setServiceCategory(serviceCategory)
                        .setQualificationId(qualificationId).setContractStartDate(contractStartDate).setContractEndDate(contractEndDate));
        return ResponseJson.success(new PaginationVo(cmProvidersList));
    }

    @GetMapping("/contract/list")
    public ResponseJson providersContractList(String contractId,
                                              @NotNull(message = "服务商ID不能为空") Integer serviceProviderId,
                                              Date contractStartDate, Date contractEndDate,
                                              @RequestParam(value = "pageNum", defaultValue = "1") int pageNum,
                                              @RequestParam(value = "pageSize", defaultValue = "20") int pageSize) {
        PageHelper.startPage(pageNum, pageSize);
        List<CmProvidersContract> cmProvidersContractList = cmProvidersContractService.getCmProvidersContractList(
                new CmProvidersContract().setContractId(contractId).setServiceProviderId(serviceProviderId)
                        .setContractStartDate(contractStartDate).setContractEndDate(contractEndDate));
        return ResponseJson.success(new PaginationVo(cmProvidersContractList));
    }

    @GetMapping("/from")
    public ResponseJson providersFrom(Integer serviceProvidersId) {
        if (null == serviceProvidersId) {
            return ResponseJson.error("协销Id不为空！");
        }
        ServiceProviderModel providers = cmProvidersService.getCmProvidersById(serviceProvidersId);
        return ResponseJson.success(providers);
    }

    @GetMapping("/contract/from")
    public ResponseJson providersContractFrom(String providersContractId) {
        if (StringUtils.isBlank(providersContractId)) {
            return ResponseJson.error("参数异常！");
        }
        CmProvidersContract providersContract = cmProvidersContractService.getCmProvidersContractById(providersContractId);
        return ResponseJson.success(providersContract);
    }

    @PostMapping("/add")
    public ResponseJson providersAdd(@RequestBody ServiceProviderModel cmProviders) {
        if (null == cmProviders.getName() || null == cmProviders.getMobile() || null == cmProviders.getServiceLevel()
                || null == cmProviders.getServiceCategory() || null == cmProviders.getAddress()
                || null == cmProviders.getTextRelateds() || null == cmProviders.getInfoRelateds()) {
            return ResponseJson.error("参数异常！");
        }
        cmProvidersService.addCmProviders(cmProviders);
        return ResponseJson.success();
    }

    @PostMapping("/updateStatus")
    public ResponseJson providersUpdateStatus(String userIds, Integer status) {
        if (null == userIds) {
            return ResponseJson.error("ID不能为空！");
        }
        for (String userId : userIds.split(",")) {
            cmProvidersService.updateCmProviders(new ServiceProviderModel().setUserId(Integer.valueOf(userId)).setStatus(status == 90 ? 90 : 91));
        }
        return ResponseJson.success();
    }

    @PostMapping("/contract/add")
    public ResponseJson providersContractAdd(@RequestBody CmProvidersContract cmProvidersContract) {
        if (null == cmProvidersContract.getServiceProviderId() || null == cmProvidersContract.getContractId()
                || null == cmProvidersContract.getContractStartDate()
                || null == cmProvidersContract.getContractEndDate() || null == cmProvidersContract.getContractRelateds()) {
            return ResponseJson.error("参数异常！");
        }
        cmProvidersContractService.addCmProvidersContract(cmProvidersContract);
        return ResponseJson.success();
    }

    @GetMapping("/download/image")
    public void downloadImage(String ids, Integer type, HttpServletRequest request, HttpServletResponse response) throws Exception {
        if (StringUtils.isBlank(ids) || null == type) {
            return;
        }
        cmProvidersService.downloadImage(ids, type, request, response);
    }
}
